@@ -6,7 +6,7 @@ use 5.010;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 use Carp qw(confess cluck);
 use Encode qw(encode decode);
@@ -167,6 +167,24 @@ sub errstr {
 	return $self->{errstr};
 }
 
+sub name_candidates {
+	my ($self) = @_;
+
+	if ( $self->{name_candidates} ) {
+		return @{ $self->{name_candidates} };
+	}
+	return;
+}
+
+sub place_candidates {
+	my ($self) = @_;
+
+	if ( $self->{place_candidates} ) {
+		return @{ $self->{place_candidates} };
+	}
+	return;
+}
+
 sub sprintf_date {
 	my ($e) = @_;
 
@@ -222,21 +240,16 @@ sub check_for_ambiguous {
 	my $s_name  = $e_name->getAttribute('state');
 
 	if ( $s_place eq 'list' ) {
-		$self->{errstr} = sprintf(
-			'Ambiguous place input: %s',
-			join( q{ | },
-				map { decode( 'UTF-8', $_->textContent ) }
-				  @{ $e_place->findnodes($xp_place_elem) } )
-		);
+		$self->{place_candidates} = [ map { decode( 'UTF-8', $_->textContent ) }
+			  @{ $e_place->findnodes($xp_place_elem) } ];
+		$self->{errstr} = 'ambiguous place parameter';
 		return;
 	}
 	if ( $s_name eq 'list' ) {
-		$self->{errstr} = sprintf(
-			'Ambiguous name input: %s',
-			join( q{ | },
-				map { decode( 'UTF-8', $_->textContent ) }
-				  @{ $e_name->findnodes($xp_name_elem) } )
-		);
+		$self->{name_candidates} = [ map { decode( 'UTF-8', $_->textContent ) }
+			  @{ $e_name->findnodes($xp_name_elem) } ];
+
+		$self->{errstr} = 'ambiguous name parameter';
 		return;
 	}
 	if ( $s_place eq 'notidentified' ) {
@@ -258,6 +271,10 @@ sub check_for_ambiguous {
 sub identified_data {
 	my ($self) = @_;
 
+	if ( not $self->{tree} ) {
+		return;
+	}
+
 	my $xp_place
 	  = XML::LibXML::XPathExpression->new('//itdOdv/itdOdvPlace/odvPlaceElem');
 	my $xp_name
@@ -273,6 +290,14 @@ sub lines {
 	my ($self) = @_;
 	my @lines;
 
+	if ( $self->{lines} ) {
+		return @{ $self->{lines} };
+	}
+
+	if ( not $self->{tree} ) {
+		return;
+	}
+
 	my $xp_element
 	  = XML::LibXML::XPathExpression->new('//itdServingLines/itdServingLine');
 
@@ -280,10 +305,6 @@ sub lines {
 	my $xp_route = XML::LibXML::XPathExpression->new('./itdRouteDescText');
 	my $xp_oper  = XML::LibXML::XPathExpression->new('./itdOperator/name');
 
-	if ( $self->{lines} ) {
-		return @{ $self->{lines} };
-	}
-
 	for my $e ( $self->{tree}->findnodes($xp_element) ) {
 
 		my $e_info  = ( $e->findnodes($xp_info) )[0];
@@ -363,6 +384,10 @@ sub results {
 	my ($self) = @_;
 	my @results;
 
+	if ( $self->{results} ) {
+		return @{ $self->{results} };
+	}
+
 	if ( not $self->{tree} ) {
 		return;
 	}
@@ -381,10 +406,6 @@ sub results {
 	my $xp_next_route
 	  = XML::LibXML::XPathExpression->new('./itdOnwardStopSeq/itdPoint');
 
-	if ( $self->{results} ) {
-		return @{ $self->{results} };
-	}
-
 	$self->lines;
 
 	for my $e ( $self->{tree}->findnodes($xp_element) ) {
@@ -553,6 +574,47 @@ sub get_efa_urls {
 			name      => 'Verkehrsverbund Stuttgart',
 			shortname => 'VVS',
 		},
+		{
+			url  => 'http://delfi1.vvo-online.de:8080/delfi3/XSLT_DM_REQUEST',
+			name => 'Verkehrsverbund Oberelbe',
+			shortname => 'VVO',
+		},
+		{
+			url       => 'http://delfi.vrn.de/delfi/XSLT_DM_REQUEST',
+			name      => 'Verkehrsverbund Rhein-Neckar (DELFI)',
+			shortname => 'VRNdelfi',
+		},
+		{
+			url       => 'http://fahrplanauskunft.vrn.de/vrn/XSLT_DM_REQUEST',
+			name      => 'Verkehrsverbund Rhein-Neckar',
+			shortname => 'VRN',
+		},
+		{
+			url       => 'http://www.efa-bw.de/nvbw/XSLT_DM_REQUEST',
+			name      => 'Nahverkehrsgesellschaft Baden-Württemberg',
+			shortname => 'NVBW',
+		},
+		{
+			url       => 'http://80.146.180.107/vmv/XSLT_DM_REQUEST',
+			name      => 'Verkehrsgesellschaft Mecklenburg-Vorpommern',
+			shortname => 'VMV',
+		},
+		{
+			url       => 'http://213.144.24.66/kvv2/XML_DM_REQUEST',
+			name      => 'Karlsruher Verkehrsverbund',
+			shortname => 'KVV',
+		},
+		{
+			url  => 'http://www.travelineeastmidlands.co.uk/em/XSLT_DM_REQUEST',
+			name => 'Traveline East Midlands',
+			shortname => 'TLEM',
+		},
+		{
+			url       => 'http://mobil.vbl.ch/vblmobil/XML_DM_REQUEST',
+			name      => 'Verkehrsbetriebe Luzern',
+			shortname => 'VBL',
+		},
+
 	);
 }
 
@@ -582,7 +644,7 @@ Travel::Status::DE::EFA - unofficial EFA departure monitor
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 DESCRIPTION
 
@@ -663,6 +725,16 @@ will return ("Essen", "Martinstr.").
 Returns a list of Travel::Status::DE::EFA::Line(3pm) objects, each one
 describing one line servicing the selected station.
 
+=item $status->name_candidates
+
+Returns a list of B<name> candidates if I<name> is ambiguous. Returns
+nothing (undef / empty list) otherwise.
+
+=item $status->place_candidates
+
+Returns a list of B<place> candidates if I<place> is ambiguous. Returns
+nothing (undef / empty list) otherwise.
+
 =item $status->results
 
 Returns a list of Travel::Status::DE::EFA::Result(3pm) objects, each one describing
